@@ -67,7 +67,7 @@ def display_alert(args,printer):
     cmd = construct_notification_command(alert_title, alert_message, urgency)
     #    pdb.set_trace()
     printer ("The Command:", str(cmd))
-    call(cmd)    
+    # call(cmd)    
     
 def play_sound(args,printer):
     a = 1
